@@ -18,6 +18,7 @@
 */
 
 #include "kacceleratormanager.h"
+#include "kacceleratormanager_p.h"
 
 #include <QApplication>
 #include <QMainWindow>
@@ -27,21 +28,17 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QMenuBar>
-#include <QMetaClassInfo>
 #include <QObject>
 #include <QList>
 #include <QPushButton>
 #include <QRadioButton>
-#include <QDoubleSpinBox>
 #include <QTabBar>
 #include <QTextEdit>
 #include <QWidget>
 #include <QStackedWidget>
 #include <QDockWidget>
-#include <QTextDocument>
-#include <QDebug>
+#include <QMetaProperty>
 
-#include "kacceleratormanager_p.h"
 #include "loggingcategory.h"
 #include "common_helpers_p.h"
 
@@ -453,20 +450,21 @@ void KAcceleratorManager::last_manage(QString &added,  QString &changed, QString
 KAccelString::KAccelString(const QString &input, int initialWeight)
     : m_pureText(input), m_weight()
 {
-    m_orig_accel = m_pureText.indexOf(QStringLiteral("(!)&"));
+    m_orig_accel = m_pureText.indexOf(QLatin1String("(!)&"));
     if (m_orig_accel != -1) {
         m_pureText.remove(m_orig_accel, 4);
     }
 
-    m_orig_accel = m_pureText.indexOf(QStringLiteral("(&&)"));
+    m_orig_accel = m_pureText.indexOf(QLatin1String("(&&)"));
     if (m_orig_accel != -1) {
         m_pureText.replace(m_orig_accel, 4, QStringLiteral("&"));
     }
 
     m_origText = m_pureText;
 
-    if (m_pureText.contains(QLatin1Char('\t'))) {
-        m_pureText = m_pureText.left(m_pureText.indexOf(QLatin1Char('\t')));
+    const int tabPos = m_pureText.indexOf(QLatin1Char('\t'));
+    if (tabPos != -1) {
+        m_pureText.truncate(tabPos);
     }
 
     m_orig_accel = m_accel = stripAccelerator(m_pureText);
@@ -492,7 +490,7 @@ QString KAccelString::accelerated() const
             int oa = m_orig_accel;
 
             if (m_accel >= 0) {
-                result.insert(m_accel, QStringLiteral("(!)&"));
+                result.insert(m_accel, QLatin1String("(!)&"));
                 if (m_accel < m_orig_accel) {
                     oa += 4;
                 }
@@ -506,7 +504,7 @@ QString KAccelString::accelerated() const
             if (m_orig_accel != -1) {
                 result.remove(m_orig_accel, 1);
             }
-            result.insert(m_accel, QStringLiteral("&"));
+            result.insert(m_accel, QLatin1Char('&'));
         }
     }
     return result;
@@ -514,7 +512,7 @@ QString KAccelString::accelerated() const
 
 QChar KAccelString::accelerator() const
 {
-    if ((m_accel < 0) || (m_accel > (int)m_pureText.length())) {
+    if ((m_accel < 0) || (m_accel > m_pureText.length())) {
         return QChar();
     }
 
@@ -549,8 +547,8 @@ void KAccelString::calculateWeights(int initialWeight)
             weight += (50 - pos);
         }
 
-        // try to preserve the wanted accelarators
-        if ((int)pos == accel()) {
+        // try to preserve the wanted accelerators
+        if (pos == accel()) {
             weight += KAccelManagerAlgorithm::WANTED_ACCEL_EXTRA_WEIGHT;
             // qCDebug(KWidgetsAddonsLog) << "wanted " << m_pureText << " " << KAcceleratorManagerPrivate::standardName(m_origText);
             if (KAcceleratorManagerPrivate::standardName(m_origText))  {
@@ -578,7 +576,7 @@ int KAccelString::stripAccelerator(QString &text)
     while (p >= 0) {
         p = text.indexOf(QLatin1Char('&'), p) + 1;
 
-        if (p <= 0 || p >= (int)text.length()) {
+        if (p <= 0 || p >= text.length()) {
             break;
         }
 
@@ -713,7 +711,7 @@ void KPopupAccelManager::aboutToShow()
 // item has been added or removed, so we can not do much more than
     // to compare the items each time the menu is shown :-(
 
-    if (m_count != (int)m_popup->actions().count()) {
+    if (m_count != m_popup->actions().count()) {
         findMenuEntries(m_entries);
         calculateAccelerators();
         m_count = m_popup->actions().count();
@@ -769,7 +767,7 @@ void KPopupAccelManager::findMenuEntries(KAccelStringList &list)
 // Duplicated from qaction.cpp
 static QString copy_of_qt_strippedText(QString s)
 {
-    s.remove(QStringLiteral("..."));
+    s.remove(QLatin1String("..."));
     for (int i = 0; i < s.size(); ++i) {
         if (s.at(i) == QLatin1Char('&')) {
             s.remove(i, 1);
